"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Text = Text;
var _reactNative = require("react-native");
var _index = require("./index.styles");
var _utils = require("../../utils");
var _theme = require("../../lib/theme");
var _breakPoint = require("../../utils/breakPoint");
var _react = _interopRequireDefault(require("react"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
// Defining a Text component with props of type TypographyI
function Text(props) {
  // Using the useTheme hook to get the current theme colors
  const {
    colors
  } = (0, _theme.useTheme)();

  // Defining the styles for the Text component
  const TextStyle = [
  // Base style
  _index.textStyle.base,
  // If underline prop is true, apply underline style
  props.underline && _index.textStyle.underline,
  // If bold prop is true, apply bold style
  props.bold && _index.textStyle.bold,
  // If italic prop is true, apply italic style
  props.italic && _index.textStyle.italic,
  // If uppercase prop is true, apply uppercase style
  props.uppercase && _index.textStyle.uppercase,
  // If lowercase prop is true, apply lowercase style
  props.lowercase && _index.textStyle.lowercase,
  // If capitalize prop is true, apply capitalize style
  props.capitalize && _index.textStyle.capitalize,
  // Apply color style. If color prop is provided, use it. Otherwise, use the FOREGROUND color from the theme
  {
    color: props.color ? props?.color : colors?.FOREGROUND || 'black'
  },
  // If fontSize prop is provided, apply fontSize style. If it's a string, use the corresponding value from the theme. Otherwise, use the prop value directly
  props?.fontSize ? {
    fontSize: typeof props.fontSize === 'string' ? _utils.theme.fontSize[props.fontSize] : props.fontSize
  } : {
    fontSize: (0, _utils.FontSize)(4.5) // Default font size
  }, props?.subscript && _index.textStyle.subscript, props?.highlight && {
    backgroundColor: colors?.ACCENT || 'yellow',
    color: colors?.ACCENT_FOREGROUND || 'black',
    paddingHorizontal: 3,
    borderRadius: 3
  }, props?.strike && _index.textStyle.strikeThrough,
  // If lineHeight prop is provided, apply lineHeight style. If it's a string, use the corresponding value from the theme. Otherwise, use the prop value directly
  props?.lineHeight && {
    lineHeight: typeof props.lineHeight === 'string' ? _utils.theme.lineHeights[props.lineHeight] : props.lineHeight
  },
  // If letterSpacing prop is provided, apply letterSpacing style. If it's a string, use the corresponding value from the theme. Otherwise, use the prop value directly
  props?.letterSpacing && {
    letterSpacing: typeof props.letterSpacing === 'string' ? _utils.theme.letterSpacings[props.letterSpacing] : props.letterSpacing
  },
  // Apply any additional styles provided through the textstyle prop
  props?.textstyle,
  // If breakpointstyle prop is provided, apply the corresponding style based on the current screen width
  props?.breakpointstyle && {
    ...(0, _breakPoint.breakPoint)(props.breakpointstyle)
  }];

  // Return the Typography component with the calculated styles and any additional props passed through TextProps
  return /*#__PURE__*/_react.default.createElement(_reactNative.Text, _extends({}, props?.TextProps, {
    style: TextStyle
  }), props?.children);
}
//# sourceMappingURL=index.js.map