"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useTheme = exports.ThemeProvider = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _color = require("./color");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const ThemeContext = /*#__PURE__*/(0, _react.createContext)(undefined);
const ThemeProvider = ({
  children,
  themeConfig = {},
  useTheme = 'light'
}) => {
  const [theme, setTheme] = (0, _react.useState)(useTheme || _reactNative.Appearance.getColorScheme() || 'light');
  (0, _react.useEffect)(() => {
    const subscription = _reactNative.Appearance.addChangeListener(({
      colorScheme
    }) => {
      setTheme(colorScheme || 'light');
    });
    return () => {
      subscription.remove();
    };
  }, []);
  const toggleTheme = () => {
    setTheme(prevTheme => {
      if (prevTheme === 'light') {
        return 'dark';
      } else if (prevTheme === 'dark') {
        return 'light';
      } else {
        return 'light';
      }
    });
  };
  const getColorsForTheme = () => {
    const themeColors = theme === 'light' ? {
      ..._color.LIGHT_THEME,
      ...themeConfig.light
    } : theme === 'dark' ? {
      ..._color.DARK_THEME,
      ...themeConfig.dark
    } : {
      ..._color.CUSTOM_THEME,
      ...themeConfig.custom
    };
    return themeColors;
  };
  const colors = getColorsForTheme();
  return /*#__PURE__*/_react.default.createElement(ThemeContext.Provider, {
    value: {
      theme: theme,
      toggleTheme,
      colors
    }
  }, children);
};
exports.ThemeProvider = ThemeProvider;
const useTheme = () => {
  const context = (0, _react.useContext)(ThemeContext);
  if (!context) {
    throw new Error('useTheme must be used within a ThemeProvider');
  }
  return context;
};
exports.useTheme = useTheme;
//# sourceMappingURL=index.js.map