import React, { createContext, useContext, useEffect, useState } from 'react';
import { Appearance } from 'react-native';
import { CUSTOM_THEME, DARK_THEME, LIGHT_THEME } from './color';
const ThemeContext = /*#__PURE__*/createContext(undefined);
export const ThemeProvider = ({
  children,
  themeConfig = {},
  useTheme = 'light'
}) => {
  const [theme, setTheme] = useState(useTheme || Appearance.getColorScheme() || 'light');
  useEffect(() => {
    const subscription = Appearance.addChangeListener(({
      colorScheme
    }) => {
      setTheme(colorScheme || 'light');
    });
    return () => {
      subscription.remove();
    };
  }, []);
  const toggleTheme = () => {
    setTheme(prevTheme => {
      if (prevTheme === 'light') {
        return 'dark';
      } else if (prevTheme === 'dark') {
        return 'light';
      } else {
        return 'light';
      }
    });
  };
  const getColorsForTheme = () => {
    const themeColors = theme === 'light' ? {
      ...LIGHT_THEME,
      ...themeConfig.light
    } : theme === 'dark' ? {
      ...DARK_THEME,
      ...themeConfig.dark
    } : {
      ...CUSTOM_THEME,
      ...themeConfig.custom
    };
    return themeColors;
  };
  const colors = getColorsForTheme();
  return /*#__PURE__*/React.createElement(ThemeContext.Provider, {
    value: {
      theme: theme,
      toggleTheme,
      colors
    }
  }, children);
};
export const useTheme = () => {
  const context = useContext(ThemeContext);
  if (!context) {
    throw new Error('useTheme must be used within a ThemeProvider');
  }
  return context;
};
//# sourceMappingURL=index.js.map