import { Text as Typography } from 'react-native';
import { textStyle } from './index.styles';
import { FontSize, theme } from '../../utils';
import { useTheme } from '../../lib/theme';
import { breakPoint } from '../../utils/breakPoint';
import type { TypographyI } from './types';
import React from 'react';

// Defining a Text component with props of type TypographyI
export function Text(props: TypographyI) {
  // Using the useTheme hook to get the current theme colors
  const { colors } = useTheme();

  // Defining the styles for the Text component
  const TextStyle: any = [
    // Base style
    textStyle.base,

    // If underline prop is true, apply underline style
    props.underline && textStyle.underline,

    // If bold prop is true, apply bold style
    props.bold && textStyle.bold,

    // If italic prop is true, apply italic style
    props.italic && textStyle.italic,

    // If uppercase prop is true, apply uppercase style
    props.uppercase && textStyle.uppercase,

    // If lowercase prop is true, apply lowercase style
    props.lowercase && textStyle.lowercase,

    // If capitalize prop is true, apply capitalize style
    props.capitalize && textStyle.capitalize,

    // Apply color style. If color prop is provided, use it. Otherwise, use the FOREGROUND color from the theme
    { color: props.color ? props?.color : colors?.FOREGROUND || 'black' },

    // If fontSize prop is provided, apply fontSize style. If it's a string, use the corresponding value from the theme. Otherwise, use the prop value directly
    props?.fontSize
      ? {
          fontSize:
            typeof props.fontSize === 'string'
              ? theme.fontSize[props.fontSize]
              : props.fontSize,
        }
      : {
          fontSize: FontSize(4.5), // Default font size
        },

    props?.subscript && textStyle.subscript,

    props?.highlight && {
      backgroundColor: colors?.ACCENT || 'yellow',
      color: colors?.ACCENT_FOREGROUND || 'black',
      paddingHorizontal: 3,
      borderRadius: 3,
    },

    props?.strike && textStyle.strikeThrough,

    // If lineHeight prop is provided, apply lineHeight style. If it's a string, use the corresponding value from the theme. Otherwise, use the prop value directly
    props?.lineHeight && {
      lineHeight:
        typeof props.lineHeight === 'string'
          ? theme.lineHeights[props.lineHeight]
          : props.lineHeight,
    },

    // If letterSpacing prop is provided, apply letterSpacing style. If it's a string, use the corresponding value from the theme. Otherwise, use the prop value directly
    props?.letterSpacing && {
      letterSpacing:
        typeof props.letterSpacing === 'string'
          ? theme.letterSpacings[props.letterSpacing]
          : props.letterSpacing,
    },

    // Apply any additional styles provided through the textstyle prop
    props?.textstyle,

    // If breakpointstyle prop is provided, apply the corresponding style based on the current screen width
    props?.breakpointstyle && {
      ...breakPoint(props.breakpointstyle),
    },
  ];

  // Return the Typography component with the calculated styles and any additional props passed through TextProps
  return (
    <Typography {...props?.TextProps} style={TextStyle}>
      {props?.children}
    </Typography>
  );
}
